![Python versions](https://img.shields.io/badge/dynamic/toml?url=https%3A%2F%2Fraw.githubusercontent.com%2FCZ-NIC%2Fyangson%2Frefs%2Fheads%2Fmaster%2Fpyproject.toml&query=%24.project.requires-python&label=python)
[![Release](https://img.shields.io/github/release/CZ-NIC/yangson.svg)](https://github.com/CZ-NIC/yangson/releases/latest)
[![License](https://img.shields.io/github/license/CZ-NIC/yangson)](COPYING.LESSER)
![Commits](https://img.shields.io/github/commit-activity/y/CZ-NIC/yangson?label=commits)
[![PyPI downloads](https://img.shields.io/pypi/dm/yangson?label=PyPI%20downloads)](https://pypi.org/project/yangson)

# Welcome to Yangson

*Yangson* is a Python 3 library for working with configuration and
state data modelled using the [YANG](https://tools.ietf.org/html/rfc7950) data modelling language.

## Installation

```shell
python -m pip install yangson
```

Note that *Yangson* requires Python 3.9 or higher.

## Development

See [instructions](https://github.com/CZ-NIC/yangson/wiki/devinstall) for installing the development environment.

## Links

* [Git repository](https://github.com/CZ-NIC/yangson)
* [Documentation](https://yangson.labs.nic.cz)
